@@ -3,10 +3,10 @@ from .destination_sftp_json.client import SftpClient
 from .destination_azblob.destination import DestinationAzBlob
 from .destination_IPFS.client import IPFSDestination
 from .source_IPFS.client import IPFSSource
-from .source_postgres.client import PostgresSource
-from .destination_postgres.client import PostgresDestination
 from .source_mysql.client import MySQLSource
 from .destination_mysql.client import MySQLDestination
+from .source_postgres.client import PostgresSource
+from .destination_postgres.client import PostgresDestination
 
 __all__ = [
     'files',
@@ -14,8 +14,9 @@ __all__ = [
     'DestinationAzBlob',
     'IPFSDestination',
     'IPFSSource',
-    'PostgresSource',
-    'PostgresDestination'
     'MySQLSource',
-    'MySQLDestination'
+    'MySQLDestination',
+    'PostgresDestination',
+    'PostgresSource'
+
 ]
